@@ -399,9 +399,11 @@ public class Browser {
 	// 
 	void OnSearchActivated (object sender, EventArgs a)
 	{
+		string term = search_term.Text;
+		if (term == "")
+			return; //Search cannot handle empty string
 		search_tree.Model = null;
 		search_term.Editable = false;
-		string term = search_term.Text;
 		//search in the index
 		Result r = search_index.Search (term);
 		if (r == null)
@@ -942,7 +944,7 @@ ExtLoop:
                 //
 		// Called on the Window delete icon clicked
 		//
-		void OnDelete (object sender, EventArgs a)
+		void OnDelete (object sender, DeleteEventArgs a)
 		{
                         AboutBox = null;
 		}
@@ -1202,7 +1204,7 @@ ExtLoop:
 		//
 		// Called on the Window delete icon clicked
 		//
-		void OnDelete (object sender, EventArgs a)
+		void OnDelete (object sender, DeleteEventArgs a)
 		{
 			config_wizard = null;
 		}
@@ -1359,7 +1361,7 @@ ExtLoop:
                 //
 		// Called on the Window delete icon clicked
 		//
-		void OnDelete (object sender, EventArgs a)
+		void OnDelete (object sender, DeleteEventArgs a)
 		{
                         NewCommentBox = null;
 		}
@@ -1404,7 +1406,7 @@ ExtLoop:
                 //
 		// Called on the Window delete icon clicked
 		//
-		void OnDelete(object sender, EventArgs a)
+		void OnDelete(object sender, DeleteEventArgs a)
 		{
                         LookupBox = null;
 		}
